@@ -2,15 +2,20 @@
 
 set -ex
 
+RED='\033[0;31m'
+NO_COLOR='\033[0m'
+
+echo -e "${RED}WARNING: This script is deprecated and it will be removed with the next release,\nplease use https://github.com/kubevirt/hyperconverged-cluster-operator/blob/master/deploy/deploy_imageregistry.sh${NO_COLOR}"
+
 globalNamespace=`oc -n openshift-operator-lifecycle-manager get deployments catalog-operator -o jsonpath='{.spec.template.spec.containers[].args[1]}'`
 echo "Global Namespace: ${globalNamespace}"
 
 TARGET_NAMESPACE="${TARGET_NAMESPACE:-openshift-cnv}"
 MARKETPLACE_NAMESPACE="${MARKETPLACE_NAMESPACE:-$globalNamespace}"
-HCO_BUNDLE_REGISTRY_TAG="${HCO_BUNDLE_REGISTRY_TAG:-v2.1.0-100}"
+HCO_BUNDLE_REGISTRY_TAG="${HCO_BUNDLE_REGISTRY_TAG:-v2.2.0-6}"
 POD_TIMEOUT="${POD_TIMEOUT:-360s}"
-CHANNEL="${CHANNEL:-2.1}"
-CNV_VERSION="${CNV_VERSION:-2.1.0}"
+CHANNEL="${CHANNEL:-2.2}"
+CNV_VERSION="${CNV_VERSION:-2.2.0}"
 CNV_CHANNEL="${CNV_VERSION:0:3}"
 
 # Use overides in the future
